@@ -60,8 +60,8 @@ markovchainSequence<-function (n, markovchain, t0 = sample(markovchain@states, 1
 }
 
 
-#function to perform random sampling
-rmarkovchain<-function(n,object,...)
+
+rmarkovchain<-function(n,object,what="data.frame",...)
 {
   if (class(object)=="markovchain") out<-markovchainSequence(n=n, markovchain=object,...)
   if (class(object)=="markovchainList")
@@ -76,22 +76,26 @@ rmarkovchain<-function(n,object,...)
       sampledValues<-markovchainSequence(n=1,markovchain=object[[1]],...)
       outIter<-rep(i,length(sampledValues))
       if(dim(object)>1)
-        {for(j in 2:dim(object))
-        {
-          pos2take<-length(sampledValues)
-          newVals<-markovchainSequence(n=1,markovchain=object[[j]],t0=sampledValues[pos2take]) #the initial state is in the ending position of the mclist
-          outIter<-c(outIter,i)
-          sampledValues<-c(sampledValues,newVals)
-        }
+      {for(j in 2:dim(object))
+      {
+        pos2take<-length(sampledValues)
+        newVals<-markovchainSequence(n=1,markovchain=object[[j]],t0=sampledValues[pos2take]) #the initial state is in the ending position of the mclist
+        outIter<-c(outIter,i)
+        sampledValues<-c(sampledValues,newVals)
+      }
       }
       iteration<-c(iteration, outIter)
       values<-c(values, sampledValues)
     }
-    out<-data.frame(iteration=iteration, values=values)
+    if (what=="data.frame") 
+      out<-data.frame(iteration=iteration, values=values)
+    else
+      out<-matrix(data=values,nrow=n,byrow=TRUE)
   }
   return(out)
 }
 
+
 #core function to get sequence matrix
 
 #createSequenceMatrix <- function(stringchar, toRowProbs = FALSE, sanitize = TRUE) {
